@@ -1,5 +1,5 @@
 
-from wcf.packages.template import train, TrainValConfigBase, t,EasyTransform
+from wcf import train, TrainValConfigBase, t,EasyTransform
 
 
 class Config(TrainValConfigBase):
